##  Next Steps
Continue learning based on the diagram type you're working with:
  * [Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Data Flow Diagrams](https://help.sap.com/docs/leanix/ea/data-flow?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Diagram Templates](https://help.sap.com/docs/leanix/ea/diagram-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Diagram templates provide reusable, standardized rules for visualizing live inventory data, enabling dynamic exploration and consistent documentation of your landscape. Use them to efficiently create, manage, and share up-to-date diagrams for analysis, stakeholder communication, and audits.")


YesNo
Send
